@@ -28,7 +28,7 @@ class Distro(Module):
                     if ret!=0:
                         raise RuntimeError
                 except:
-                    target.Pip.install('httpie')
+                    target.pip.install('httpie')
                     ret, out, err = target.run(f'http --download {url} -o {dst}')
                     if ret!=0:
                         msg = err[0]
