@@ -7,7 +7,7 @@ class Distro(Module):
     '''Show infos
     '''
     def deploy(self, target, **kw):
-        user = 'sudo' if target.sudo else target.login.name
+        user = target.login.name
         os = target.os
         python = target.run('python3 -V')[1][0]
         host = target.distro.host
